@@ -379,15 +379,15 @@ int  ssm::Superpose::GetNAlign()  {
 
 void  ssm::Superpose::GetSuperposition ( mmdb::ivector  & Ca1  ,
                                          mmdb::rvector  & dist1,
-                                         int      & nCa1 ,
+                                         int            & nCa1 ,
                                          mmdb::ivector  & Ca2  ,
-                                         int      & nCa2 ,
+                                         int            & nCa2 ,
                                          mmdb::mat44    & TMat ,
                                          mmdb::realtype & rmsdAchieved,
-                                         int      & nAligned    ,
-                                         int      & nGaps       ,
+                                         int            & nAligned    ,
+                                         int            & nGaps       ,
                                          mmdb::realtype & seqIdentity ,
-                                         int      & nMisD       ,
+                                         int            & nMisD       ,
                                          mmdb::realtype & nCombs )  {
 //
 //   Ca1[i]>=0 gives the index of Calpha of 2nd structure,
@@ -447,12 +447,14 @@ int i,j;
 }
 
 
-void ssm::Superpose::GetCalphas1 ( mmdb::PPAtom & Calpha, int & numRes )  {
+void ssm::Superpose::GetCalphas1 ( mmdb::PPAtom & Calpha,
+                                   int & numRes )  {
   Calpha = Calpha1;
   numRes = nres1;
 }
 
-void ssm::Superpose::GetCalphas2 ( mmdb::PPAtom & Calpha, int & numRes )  {
+void ssm::Superpose::GetCalphas2 ( mmdb::PPAtom & Calpha,
+                                   int & numRes )  {
   Calpha = Calpha2;
   numRes = nres2;
 }
@@ -587,7 +589,8 @@ void SMinTFunc::Dispose()  {
   Init();
 }
 
-void  MinTFunc ( void * Data, int N, mmdb::rvector X, mmdb::realtype & F )  {
+void  MinTFunc ( void * Data, int N, mmdb::rvector X,
+                                     mmdb::realtype & F )  {
 UNUSED_ARGUMENT(N);
 PSMinTFunc     MTFD;
 mmdb::mat33    erm;
